Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(259)

Unified Diff: ipc/param_traits_size_macros.h

Issue 1655333002: Add message sizing to basic IPC traits and struct macros. (Closed) Base URL: https://chromium.googlesource.com/chromium/src.git@with-pickles
Patch Set: include ArrayHeader in size (oops!) and ensure the buffer doesn't relocate Created 4 years, 10 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « ipc/param_traits_macros.h ('k') | mojo/public/cpp/bindings/lib/native_serialization.h » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: ipc/param_traits_size_macros.h
diff --git a/ipc/param_traits_write_macros.h b/ipc/param_traits_size_macros.h
similarity index 55%
copy from ipc/param_traits_write_macros.h
copy to ipc/param_traits_size_macros.h
index a1aca4374eb3230c3b8e72c86f73ed3deb8d941d..142b55a32d646c72e536a3623217ec8a1940cf9b 100644
--- a/ipc/param_traits_write_macros.h
+++ b/ipc/param_traits_size_macros.h
@@ -1,9 +1,9 @@
-// Copyright (c) 2012 The Chromium Authors. All rights reserved.
+// Copyright 2016 The Chromium Authors. All rights reserved.
// Use of this source code is governed by a BSD-style license that can be
// found in the LICENSE file.
-#ifndef IPC_PARAM_TRAITS_WRITE_MACROS_H_
-#define IPC_PARAM_TRAITS_WRITE_MACROS_H_
+#ifndef IPC_PARAM_TRAITS_SIZE_MACROS_H_
+#define IPC_PARAM_TRAITS_SIZE_MACROS_H_
// Null out all the macros that need nulling.
#include "ipc/ipc_message_null_macros.h"
@@ -17,24 +17,24 @@
#define IPC_STRUCT_MEMBER(type, name, ...) IPC_STRUCT_TRAITS_MEMBER(name)
#define IPC_STRUCT_END() IPC_STRUCT_TRAITS_END()
// Set up so next include will generate write methods.
#undef IPC_STRUCT_TRAITS_BEGIN
#undef IPC_STRUCT_TRAITS_MEMBER
#undef IPC_STRUCT_TRAITS_PARENT
#undef IPC_STRUCT_TRAITS_END
#define IPC_STRUCT_TRAITS_BEGIN(struct_name) \
- void ParamTraits<struct_name>::Write(base::Pickle* m, const param_type& p) {
-#define IPC_STRUCT_TRAITS_MEMBER(name) WriteParam(m, p.name);
-#define IPC_STRUCT_TRAITS_PARENT(type) ParamTraits<type>::Write(m, p);
+ void ParamTraits<struct_name>::GetSize(base::PickleSizer* sizer, \
+ const param_type& p) {
+#define IPC_STRUCT_TRAITS_MEMBER(name) GetParamSize(sizer, p.name);
+#define IPC_STRUCT_TRAITS_PARENT(type) ParamTraits<type>::GetSize(sizer, p);
#define IPC_STRUCT_TRAITS_END() }
#undef IPC_ENUM_TRAITS_VALIDATE
#define IPC_ENUM_TRAITS_VALIDATE(enum_name, validation_expression) \
- void ParamTraits<enum_name>::Write(base::Pickle* m, \
- const param_type& value) { \
- DCHECK(validation_expression); \
- m->WriteInt(static_cast<int>(value)); \
+ void ParamTraits<enum_name>::GetSize(base::PickleSizer* sizer, \
+ const param_type& value) { \
+ sizer->AddInt(); \
}
-#endif // IPC_PARAM_TRAITS_WRITE_MACROS_H_
+#endif // IPC_PARAM_TRAITS_SIZE_MACROS_H_
« no previous file with comments | « ipc/param_traits_macros.h ('k') | mojo/public/cpp/bindings/lib/native_serialization.h » ('j') | no next file with comments »

Powered by Google App Engine
@@ -17,24 +17,24 @@
#define IPC_STRUCT_MEMBER(type, name, ...) IPC_STRUCT_TRAITS_MEMBER(name)
#define IPC_STRUCT_END() IPC_STRUCT_TRAITS_END()
-// Set up so next include will generate write methods.
+// Set up so next include will generate size methods.
#undef IPC_STRUCT_TRAITS_BEGIN
#undef IPC_STRUCT_TRAITS_MEMBER
This is Rietveld 408576698